Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(570)

Unified Diff: services/ui/ws/cursor_state.h

Issue 2949353003: Implement large cursors in Mushrome. (Closed)
Patch Set: rename everything to CursorSize Created 3 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « services/ui/public/interfaces/window_manager.mojom ('k') | services/ui/ws/cursor_state.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: services/ui/ws/cursor_state.h
diff --git a/services/ui/ws/cursor_state.h b/services/ui/ws/cursor_state.h
index b6af262b57eb644341c40243fc2f0ce02eab0358..7fd12c4308e7f93dfc12ecc509131041904bee5c 100644
--- a/services/ui/ws/cursor_state.h
+++ b/services/ui/ws/cursor_state.h
@@ -11,6 +11,9 @@
#include "ui/base/cursor/cursor_data.h"
namespace ui {
+
+enum class CursorSize;
+
namespace ws {
class DisplayManager;
@@ -36,11 +39,17 @@ class CursorState {
// Sets a cursor globally, which overrides the per-window cursors.
void SetGlobalOverrideCursor(const base::Optional<ui::CursorData>& cursor);
+ // Sets the cursor size.
+ void SetCursorSize(ui::CursorSize cursor_size);
+
private:
// A snapshot of the cursor state at a specific time.
class StateSnapshot;
- // Synchronizes |current_state_| with all the platform displays.
+ // Synchronizes cursor set data with all platform displays.
+ void SetPlatformCursorSize();
+
+ // Synchronizes the current cursor state with all the platform displays.
void SetPlatformCursor();
// Contains are the displays we notify on cursor changes.
« no previous file with comments | « services/ui/public/interfaces/window_manager.mojom ('k') | services/ui/ws/cursor_state.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698